"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_ilogger_1 = require("typescript-ilogger");
const test_values_1 = require("./test-values");
const helper_1 = require("./helper");
const error = new Error(`AWS Error`);
const createQueue = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const deleteMessage = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const deleteMessageBatch = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const deleteQueue = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const getQueueAttributes = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const purgeQueue = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const receiveMessage = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const sendMessage = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const sendMessageBatch = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
jest.mock('@aws-sdk/client-sqs', () => {
    return {
        SQS: jest.fn().mockImplementation(() => {
            return {
                createQueue,
                deleteMessage,
                deleteMessageBatch,
                deleteQueue,
                getQueueAttributes,
                purgeQueue,
                receiveMessage,
                sendMessage,
                sendMessageBatch,
            };
        }),
    };
});
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const sqsHelperMock = new helper_1.SQSHelper(logger);
const TestValues = new test_values_1.TestingValues();
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.CreateQueueAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = sqsHelperMock.CreateQueueAsync(TestValues.Url, {});
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.DeleteMessageAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = sqsHelperMock.DeleteMessageAsync(TestValues.Url, TestValues.ReceiptHandle);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.DeleteMessagesAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = sqsHelperMock.DeleteMessagesAsync(TestValues.Url, [
            TestValues.ReceiptHandle,
        ]);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.DeleteQueueAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = sqsHelperMock.DeleteQueueAsync(TestValues.Url);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.GetNumberOfMessagesOnQueueAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = sqsHelperMock.GetNumberOfMessagesOnQueueAsync(TestValues.Url);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.GetQueueAttributesAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = sqsHelperMock.GetQueueAttributesAsync(TestValues.Url);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.PurgeQueueAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = sqsHelperMock.PurgeQueueAsync(TestValues.Url);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.ReceiveMessagesAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = sqsHelperMock.ReceiveMessagesAsync(TestValues.Url);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.SendMessageAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = sqsHelperMock.SendMessageAsync(TestValues.Url, TestValues.Body);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.SendMessagesAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = sqsHelperMock.SendMessagesAsync(TestValues.Url, TestValues.Entries);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
//# sourceMappingURL=helper-rejects.spec.js.map