"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_ilogger_1 = require("typescript-ilogger");
const test_values_1 = require("./test-values");
const helper_1 = require("./helper");
const createQueueResultResponse = {};
const deleteMessageOutputResponse = { Failed: [], Successful: [] };
const deleteMessageBatchResultResponse = {
    Failed: [],
    Successful: [],
};
const deleteQueueResultResponse = {};
const getQueueAttributesResultResponse = {
    Attributes: { ApproximateNumberOfMessages: '5' },
};
const purgeQueueResultResponse = {};
const receiveMessageResultResponse = { Messages: [] };
const sendMessageResultResponse = {};
const sendMessageBatchResultResponse = {
    Failed: [],
    Successful: [],
};
const createQueue = jest.fn().mockImplementation(() => {
    return Promise.resolve(createQueueResultResponse);
});
const deleteMessage = jest.fn().mockImplementation(() => {
    return Promise.resolve(deleteMessageOutputResponse);
});
const deleteMessageBatch = jest.fn().mockImplementation(() => {
    return Promise.resolve(deleteMessageBatchResultResponse);
});
const deleteQueue = jest.fn().mockImplementation(() => {
    return Promise.resolve(deleteQueueResultResponse);
});
const getQueueAttributes = jest.fn().mockImplementation(() => {
    return Promise.resolve(getQueueAttributesResultResponse);
});
const purgeQueue = jest.fn().mockImplementation(() => {
    return Promise.resolve(purgeQueueResultResponse);
});
const receiveMessage = jest.fn().mockImplementation(() => {
    return Promise.resolve(receiveMessageResultResponse);
});
const sendMessage = jest.fn().mockImplementation(() => {
    return Promise.resolve(sendMessageResultResponse);
});
const sendMessageBatch = jest.fn().mockImplementation(() => {
    return Promise.resolve(sendMessageBatchResultResponse);
});
jest.mock('@aws-sdk/client-sqs', () => {
    return {
        SQS: jest.fn().mockImplementation(() => {
            return {
                createQueue,
                deleteMessage,
                deleteMessageBatch,
                deleteQueue,
                getQueueAttributes,
                purgeQueue,
                receiveMessage,
                sendMessage,
                sendMessageBatch,
            };
        }),
    };
});
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const sqsHelperMock = new helper_1.SQSHelper(logger);
const TestValues = new test_values_1.TestingValues();
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.CreateQueueAsync.name}`, () => {
    const action = `${helper_1.SQSHelper.name}.${sqsHelperMock.CreateQueueAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} queueName`, () => {
        const actual = sqsHelperMock.CreateQueueAsync(TestValues.EmptyString, {});
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} queueName`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = sqsHelperMock.CreateQueueAsync(TestValues.Url, {});
        return expect(actual).resolves.toEqual(createQueueResultResponse);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.DeleteMessageAsync.name}`, () => {
    const action = `${helper_1.SQSHelper.name}.${sqsHelperMock.DeleteMessageAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} queueUrl`, () => {
        const actual = sqsHelperMock.DeleteMessageAsync(TestValues.EmptyString, TestValues.ReceiptHandle);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} queueUrl`);
    });
    test(`${TestValues.ThrowsOnEmpty} receiptHandle`, () => {
        const actual = sqsHelperMock.DeleteMessageAsync(TestValues.Url, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} receiptHandle`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = sqsHelperMock.DeleteMessageAsync(TestValues.Url, TestValues.ReceiptHandle);
        return expect(actual).resolves.toEqual(deleteMessageOutputResponse);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.DeleteMessagesAsync.name}`, () => {
    const action = `${helper_1.SQSHelper.name}.${sqsHelperMock.DeleteMessagesAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} queueUrl`, () => {
        const actual = sqsHelperMock.DeleteMessagesAsync(TestValues.EmptyString, [
            TestValues.ReceiptHandle,
        ]);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} queueUrl`);
    });
    test(`${TestValues.ThrowsOnEmpty} receiptHandles`, () => {
        const actual = sqsHelperMock.DeleteMessagesAsync(TestValues.Url, TestValues.EmptyArray);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} at least one receiptHandle`);
    });
    test(`${TestValues.ThrowsOnTooMany} receiptHandles`, () => {
        const actual = sqsHelperMock.DeleteMessagesAsync(TestValues.Url, [
            TestValues.StringValue,
            TestValues.StringValue,
            TestValues.StringValue,
            TestValues.StringValue,
            TestValues.StringValue,
            TestValues.StringValue,
            TestValues.StringValue,
            TestValues.StringValue,
            TestValues.StringValue,
            TestValues.StringValue,
            TestValues.StringValue,
        ]);
        return expect(actual).rejects.toThrow(`[${action}]-Can only supply up to 10 receiptHandles`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = sqsHelperMock.DeleteMessagesAsync(TestValues.Url, [
            TestValues.ReceiptHandle,
        ]);
        return expect(actual).resolves.toEqual(deleteMessageOutputResponse);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.DeleteQueueAsync.name}`, () => {
    const action = `${helper_1.SQSHelper.name}.${sqsHelperMock.DeleteQueueAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} queueUrl`, () => {
        const actual = sqsHelperMock.DeleteQueueAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} queueUrl`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = sqsHelperMock.DeleteQueueAsync(TestValues.Url);
        return expect(actual).resolves.toEqual(deleteQueueResultResponse);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.GetNumberOfMessagesOnQueueAsync.name}`, () => {
    const action = `${helper_1.SQSHelper.name}.${sqsHelperMock.GetNumberOfMessagesOnQueueAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} queueUrl`, () => {
        const actual = sqsHelperMock.GetNumberOfMessagesOnQueueAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} queueUrl`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = sqsHelperMock.GetNumberOfMessagesOnQueueAsync(TestValues.Url);
        return expect(actual).resolves.toBe(5);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.GetQueueAttributesAsync.name}`, () => {
    const action = `${helper_1.SQSHelper.name}.${sqsHelperMock.GetQueueAttributesAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} queueUrl`, () => {
        const actual = sqsHelperMock.GetQueueAttributesAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} queueUrl`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = sqsHelperMock.GetQueueAttributesAsync(TestValues.Url);
        return expect(actual).resolves.toBe(getQueueAttributesResultResponse.Attributes);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.PurgeQueueAsync.name}`, () => {
    const action = `${helper_1.SQSHelper.name}.${sqsHelperMock.PurgeQueueAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} queueUrl`, () => {
        const actual = sqsHelperMock.PurgeQueueAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} queueUrl`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = sqsHelperMock.PurgeQueueAsync(TestValues.Url);
        return expect(actual).resolves.toEqual(purgeQueueResultResponse);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.ReceiveMessagesAsync.name}`, () => {
    const action = `${helper_1.SQSHelper.name}.${sqsHelperMock.ReceiveMessagesAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} queueUrl`, () => {
        const actual = sqsHelperMock.ReceiveMessagesAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} queueUrl`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = sqsHelperMock.ReceiveMessagesAsync(TestValues.Url);
        return expect(actual).resolves.toEqual(receiveMessageResultResponse);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.SendMessageAsync.name}`, () => {
    const action = `${helper_1.SQSHelper.name}.${sqsHelperMock.SendMessageAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} queueUrl`, () => {
        const actual = sqsHelperMock.SendMessageAsync(TestValues.EmptyString, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} queueUrl`);
    });
    test(`${TestValues.ThrowsOnEmpty} messageBody`, () => {
        const actual = sqsHelperMock.SendMessageAsync(TestValues.Url, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} messageBody`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = sqsHelperMock.SendMessageAsync(TestValues.Url, TestValues.Body);
        return expect(actual).resolves.toEqual(sendMessageResultResponse);
    });
});
describe(`${helper_1.SQSHelper.name}.${sqsHelperMock.SendMessagesAsync.name}`, () => {
    const action = `${helper_1.SQSHelper.name}.${sqsHelperMock.SendMessagesAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} queueUrl`, () => {
        const actual = sqsHelperMock.SendMessagesAsync(TestValues.EmptyString, TestValues.Entries);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} queueUrl`);
    });
    test(`${TestValues.ThrowsOnEmpty} entries`, () => {
        const actual = sqsHelperMock.SendMessagesAsync(TestValues.Url, TestValues.EmptyArray);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} at least one entry`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = sqsHelperMock.SendMessagesAsync(TestValues.Url, TestValues.Entries);
        return expect(actual).resolves.toEqual(sendMessageBatchResultResponse);
    });
});
//# sourceMappingURL=helper-resolves.spec.js.map